POS_MAP = {
    "v": ["Verb"],
    "n": [
        "Noun",
        "Proper noun",
        "Letter",
        "Symbol",
        "Abbreviation",
        "Pronoun",
        "Initialism",
        "Contraction",
        "Acronym",
    ],
    "a": ["Adjective", "Number", "Numeral", "Participle", "Ordinal number"],
    "r": ["Adverb"],
}

UD_POS_MAP = {
    "v": ["VERB", "AUX"],
    "n": ["NOUN", "PROPN", "SYM", "PRON"],
    "a": ["ADJ", "NUM"],
    "r": ["ADV", "ADP"],
}
